Вход в сайта
Description: Обяви . Работа . Апартаменти . Къщи . Наеми . Автомобили . Коли . Камиони . Екскурзии . Почивки . Заведения . Обучения . Курсове . GSM . Електроника . Компютри . Офис техника . Машини . инструменти . ..
Keywords: Вход,Vhod,сайта,sayta

Към началната страница
Вход в сайта »

# Вход в alo.bg и realestates.bg

потребителско име*: |  | Регистрация » Забравена парола »
парола*: |

### Ако не желаете да се регистрирате, то може да публикувате обява през нашият колцентър

0900 630 10
Едновременно публикувате и в сайта, и във вестника
Може да публикувате до 3 обяви с едно обаждане
Цена 1.20лв. с ДДС за целия разговор
Възможни са ограничения. Виж повече.
Публикуване на обяви в сайта и вестника по телефона (1.20 лв. на обаждане)

- Може да публикувате до 3 обяви едновременно в сайта и вестници АЛО с едно обаждане.
- Обаждането се таксува по 1.20 лв. с ДДС без значение на продължителността му.
- Не може да публикувате обяви в следните рубрики: "Работа в чужбина", "Надомна работа", "Запознанства/Ескорт", "Окултни услуги", "Кредити/Залози"!
- 0900 630 10 - за абонати на Mtel, Vivacom, Globul, Bob (1.20 лв. за целия разговор)

Важно!
Препоръчително е първия път да се обадите в работното време на колцентъра (работни дни 08:00 - 16:00 ч.), за да ви обслужи наш оператор.
Ако все пак се обадите в извънработно време, продиктувайте на телефонния ни секретар задължителните параметри за вашите обяви:

- телефон/и за връзка
- населеното място, за което се отнася обявата
- вестниците, в които да бъде публикувана - София, Пловдив, Стара Загора, Бургас, Сливен или Ямбол
- подробно описание на обявата - за да можем да публикуваме обявата ви и в интернет, моля разгледайте структурата на сайта в желаната рубрика от тук.
- Примери:
  - Ако публикувате автомобил, посочете марка, модел, модификация, вид на двигателя, година на производство, цвят, мощност, екстри и цена.
  - Ако публикувате недвижим имот, посочете населено място, квартал, вид на имота, квадратура, етаж, вид строителство, екстри и цена.
- диктувайте обявата си бавно и отчетливо - цената на разговора не зависи от продължителността му.
- обявите, публикувани през телефонния ни секретар, ще бъдат публикувани в сайта на следващия работен ден, а във вестника - в следващия брой.
- обявата в сайта ще е валидна до датата, в която се разпространява следващият брой на вестника.
  - Пример: ако публикувате обявата си в петък сутрин, тя ще излезе в сайта веднага, във вестник АЛО - София ще излезе в следващия брой в понеделник и двете обяви ще бъдат активни до следващата неделя.

Публикуване на обяви със снимки от мобилен телефон през нашият колцентър Посетете http://m.alo.bg/publish/ или сканирайте кода в дясно Качете снимките Обадете се на нашият колцентър 090063010 Едновременно публикувате и в сайта, и във вестника Може да публикувате до 3 обяви с едно обаждане Цена 1.20лв. с ДДС за целия разговор |

﻿